import {UsageParameter} from '../../erp/rtgm';
import {Location} from '../../nshmp-lib/geo';
import {Response} from '../../nshmp-ws-utils';

/** NCM geophysical service response. */
export type GeophysicalResponse = Response<
  GeophysicalRequestData,
  GeophysicalResponseData
>;

export interface GeophysicalRequestData {
  location: Location;
  depths: DepthRequestData;
}

export interface DepthRequestData {
  depth_min: number;
  depth_inc: number;
  depth_max: number;
  depth_vector: number[];
  units: string;
}

export interface GeophysicalResponseData {
  metadata: GeophysicalResponseMetadata;
  results: GeophysicalResults[];
}

export interface GeophysicalResponseMetadata {
  water_table_depth: UsageParameter;
  temperature: UsageParameter;
  porosity: UsageParameter;
  vs: UsageParameter;
  vp: UsageParameter;
  density: UsageParameter;
}

export interface GeophysicalResults {
  location: LocationResults;
  profile: Profiles;
}

export interface LocationResults extends Location {
  water_table_depth: number;
}

export interface Profiles {
  temperature: number[];
  porosity: number[];
  vs: number[];
  vp: number[];
  density: number[];
}
