import {Imt} from '../../../nshmp-lib/gmm';
import {Response} from '../../../nshmp-ws-utils';
import {Parameter, Server} from '../../../nshmp-ws-utils/metadata';
import {HazardRequestData} from '../hazard-service/hazard-response.model';

export type DisaggResponse = Response<DisaggRequestData, DisaggResponseData>;

export enum DataType {
  GMM = 'GMM',
  SOURCE = 'SOURCE',
  DISAGG_DATA = 'DISAGG_DATA',
}

export interface DisaggRequestData extends HazardRequestData {
  imts: Imt[];
  returnPeriod: number;
  dataTypes: DataType[];
}

export interface DisaggResponseMetadata {
  rlabel: string;
  mlabel: string;
  εlabel: string;
  εbins: EBin[];
  server: Server;
}

export interface EBin {
  id: number;
  min: number;
  max: number;
}

export interface DisaggResponseData {
  metadata: DisaggResponseMetadata;
  disaggs: DisaggResponseDataValues[];
}

export interface DisaggResponseDataValues {
  imt: Parameter;
  data: DisaggComponentData[];
}

export interface DisaggComponentData {
  component: string;
  data: DisaggData[];
  summary: DisaggSummary[];
  sources: DisaggSource[];
}

export interface DisaggData {
  r: number;
  m: number;
  rBar: number;
  mBar: number;
  εBar: number;
  εdata: EData[];
}

export interface EData {
  εbin: number;
  value: number;
}

export interface DisaggSummary {
  name: string;
  display: boolean;
  data: DisaggSummaryData[];
}

export interface DisaggSummaryData {
  name: string;
  value: number;
  units: string;
}

export interface DisaggSource {
  name: string;
  source: string;
  type: string;
  contribution: number;
  id: number;
  r: number;
  m: number;
  ε: number;
  azimuth: number;
  longitude: number;
  latitude: number;
}
