import {XySequence} from '../../../nshmp-lib/data';
import {Imt} from '../../../nshmp-lib/gmm';
import {Response} from '../../../nshmp-ws-utils';
import {Parameter, Server} from '../../../nshmp-ws-utils/metadata';

/**
 * The hazard calculation response.
 */
export type HazardCalcResponse = Response<
  HazardRequestData,
  HazardResponseData
>;

/*
 * The hazard service request data.
 *
 * Ported from: https://code.usgs.gov/ghsc/nshmp/nshmp-haz-v2
 *    /-/blob/master/src/main/java/gov/usgs/earthquake/nshmp/www/services/HazardService.java
 */
export interface HazardRequestData {
  imts: Imt[];
  latitude: number;
  longitude: number;
  maxdir: boolean;
  truncate: boolean;
  vs30: number;
}

/*
 * The hazard service calculation response data.
 *
 * Ported from: https://code.usgs.gov/ghsc/nshmp/nshmp-haz-v2
 *    /-/blob/master/src/main/java/gov/usgs/earthquake/nshmp/www/services/HazardService.java
 */
export interface HazardResponseData {
  metadata: HazardResponseMetadata;
  hazardCurves: HazardResponse[];
}

/*
 * The hazard service calculation response.
 *
 * Ported from: https://code.usgs.gov/ghsc/nshmp/nshmp-haz-v2
 *    /-/blob/master/src/main/java/gov/usgs/earthquake/nshmp/www/services/HazardService.java
 */
export interface HazardResponse {
  imt: Parameter;
  data: HazardCurve[];
}

/*
 * The hazard service calculation response metadata.
 *
 * Ported from: https://code.usgs.gov/ghsc/nshmp/nshmp-haz-v2
 *    /-/blob/master/src/main/java/gov/usgs/earthquake/nshmp/www/services/HazardService.java
 */
export interface HazardResponseMetadata {
  xlabel: string;
  ylabel: string;
  server: Server;
}

/*
 * The hazard service hazard curve.
 *
 * Ported from: https://code.usgs.gov/ghsc/nshmp/nshmp-haz-v2
 *    /-/blob/master/src/main/java/gov/usgs/earthquake/nshmp/www/services/HazardService.java
 */
export interface HazardCurve {
  component: string;
  values: XySequence;
}
