export enum Imt {
  PGA = 'PGA',
  PGV = 'PGV',
  PGD = 'PGD',
  ASI = 'ASI',
  SI = 'SI',
  DSI = 'DSI',
  CAV = 'CAV',
  DS575 = 'DS575',
  DS595 = 'DS595',
  AI = 'AI',
  SA0P01 = 'SA0P01',
  SA0P02 = 'SA0P02',
  SA0P025 = 'SA0P025',
  SA0P03 = 'SA0P03',
  SA0P04 = 'SA0P04',
  SA0P05 = 'SA0P05',
  SA0P06 = 'SA0P06',
  SA0P07 = 'SA0P07',
  SA0P075 = 'SA0P075',
  SA0P08 = 'SA0P08',
  SA0P09 = 'SA0P09',
  SA0P1 = 'SA0P1',
  SA0P12 = 'SA0P12',
  SA0P14 = 'SA0P14',
  SA0P15 = 'SA0P15',
  SA0P16 = 'SA0P16',
  SA0P17 = 'SA0P17',
  SA0P18 = 'SA0P18',
  SA0P2 = 'SA0P2',
  SA0P25 = 'SA0P25',
  SA0P3 = 'SA0P3',
  SA0P35 = 'SA0P35',
  SA0P4 = 'SA0P4',
  SA0P45 = 'SA0P45',
  SA0P5 = 'SA0P5',
  SA0P6 = 'SA0P6',
  SA0P7 = 'SA0P7',
  SA0P75 = 'SA0P75',
  SA0P8 = 'SA0P8',
  SA0P9 = 'SA0P9',
  SA1P0 = 'SA1P0',
  SA1P25 = 'SA1P25',
  SA1P5 = 'SA1P5',
  SA2P0 = 'SA2P0',
  SA2P5 = 'SA2P5',
  SA3P0 = 'SA3P0',
  SA3P5 = 'SA3P5',
  SA4P0 = 'SA4P0',
  SA4P5 = 'SA4P5',
  SA5P0 = 'SA5P0',
  SA6P0 = 'SA6P0',
  SA7P5 = 'SA7P5',
  SA10P0 = 'SA10P0',
}

export const imtToPeriod = (imt: Imt): number => {
  if (imt === Imt.PGA || imt === Imt.PGV) {
    return 0.001;
  } else if (imt.startsWith('SA')) {
    return Number(imt.substring(2).replace('P', '.'));
  } else {
    throw new Error(`Cannot convert ${imt}`);
  }
};

export const imtToString = (imt: Imt): string => {
  switch (imt) {
    case Imt.PGA:
      return 'Peak Ground Acceleration';
    case Imt.PGV:
      return 'Peak Ground Velocity';
    case Imt.PGD:
      return 'Peak Ground Displacement';
    case Imt.AI:
      return 'Arias Intensity';
    case Imt.ASI:
      return 'Acceleration Spectrum Intensity';
    case Imt.DSI:
      return 'Displacement Spectrum Intensity';
    case Imt.SI:
      return 'Spectrum intensity';
    case Imt.CAV:
      return 'Cumulative Absolute Velocity';
    case Imt.DS575:
      return 'Significant Duration 5-75%';
    case Imt.DS595:
      return 'Significant Duration 5-95%';
    default:
      return `${imtToPeriod(imt)} Second Spectral Acceleration`;
  }
};

export const imtToUnits = (imt: Imt): string => {
  switch (imt) {
    case Imt.PGA:
      return 'g';
    case Imt.PGV:
      return 'cm/s';
    case Imt.PGD:
      return 'cm';
    case Imt.AI:
      return 'm/s';
    case Imt.ASI:
      return 'g⋅s';
    case Imt.DSI:
      return 'cm⋅s';
    case Imt.SI:
      return 'cm⋅s/s';
    case Imt.CAV:
      return 'g⋅s';
    case Imt.DS575:
      return 's';
    case Imt.DS595:
      return 's';
    default:
      return 'g';
  }
};
