import {NshmRegion} from './nshm-region.model';

/**
 * ID for NSHMs
 */
export enum NshmId {
  ALASKA_1999 = 'ALASKA_1999',
  ALASKA_2007 = 'ALASKA_2007',
  ALASKA_2023 = 'ALASKA_2023',
  AMSAM_2012 = 'AMSAM_2012',
  CONUS_2002 = 'CONUS_2002',
  CONUS_2008 = 'CONUS_2008',
  CONUS_2014 = 'CONUS_2014',
  CONUS_2018 = 'CONUS_2018',
  CONUS_2023 = 'CONUS_2023',
  GNMI_2012 = 'GNMI_2012',
  HAWAII_1998 = 'HAWAII_1998',
  HAWAII_2021 = 'HAWAII_2021',
  PRVI_2003 = 'PRVI_2003',
}

/**
 * Returns the region associated with the NSHM.
 *
 * @param nshmId The NSHM id
 */
export function nshmRegion(nshmId: NshmId): NshmRegion {
  const region = nshmId.split('_').shift();

  if (region === undefined) {
    throw new Error(`NSHM ${nshmId} not supported`);
  }

  return region as NshmRegion;
}

/**
 * Returns the year associated with NSHM.
 *
 * @param nshmId The NSHM id
 */
export function nshmYear(nshmId: NshmId): number {
  const year = nshmId.split('_').pop();

  if (year === undefined) {
    throw new Error(`NSHM ${nshmId} not supported`);
  }

  return Number.parseInt(year);
}
