import {XyDataGroup} from '../../nshmp-haz';
import {XySequence} from '../../nshmp-lib/data';
import {GmmInput} from '../../nshmp-lib/gmm';
import {Response} from '../../nshmp-ws-utils';
import {Parameter} from '../../nshmp-ws-utils/metadata';

export type GmmSpectraResponse = Response<
  GmmRequestData,
  GmmResponseData<SpectraData, TreeValues>
>;

export type GmmDistanceResponse = Response<
  GmmRequestDataDistance,
  GmmResponseData<XySequence, number[]>
>;

export type GmmMagnitudeResponse = Response<
  GmmRequestDataMagnitude,
  GmmResponseData<XySequence, number[]>
>;

export interface GmmResponseData<T, U> {
  means: XyDataGroup<GmmSeries<T, U>>;
  sigmas: XyDataGroup<GmmSeries<T, U>>;
}

export interface GmmRequestData {
  gmms: string[];
  input: GmmInput;
}

export interface GmmRequestDataDistance extends GmmRequestData {
  imt: Parameter;
  rMin: number;
  rMax: number;
}

export interface GmmRequestDataMagnitude extends GmmRequestData {
  imt: Parameter;
  mMin: number;
  mMax: number;
  distance: number;
  step: number;
}

export interface SpectraSeries {
  id: string;
  label: string;
  data: object;
  tree: object;
}

export interface SpectraData {
  pga: number | null;
  pgv: number | null;
  sa: XySequence;
}

export interface GmmSeries<T, U> {
  id: string;
  label: string;
  data: T;
  tree: LogicTree<U>[];
}

export interface TreeValues {
  pga: number | null;
  pgv: number | null;
  sa: number[];
}

export interface LogicTree<T> {
  id: string;
  values: T;
  weights: T;
}
